changeset 953:7c035a87c691

*** empty log message ***
author Roland McGrath <roland@gnu.org>
date Mon, 10 Aug 1992 21:24:45 +0000
parents ba6a993500d4
children 9e51bb887797
files lisp/add-log.el
diffstat 1 files changed, 28 insertions(+), 22 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/add-log.el	Sat Aug 08 22:58:39 1992 +0000
+++ b/lisp/add-log.el	Mon Aug 10 21:24:45 1992 +0000
@@ -287,28 +287,34 @@
 					     (progn (forward-sexp 1) (point))))
 		       ;; Ordinary C function syntax.
 		       (setq beg (point))
-		       (down-list 1)	; into arglist
-		       (backward-up-list 1)
-		       (skip-chars-backward " \t")
-		       ;; Verify initial pos was after real start of function.
-		       (if (and (save-excursion
-				  (goto-char beg)
-				  ;; For this purpose, include the line
-				  ;; that has the decl keywords.
-				  ;; This may also include some of the comments
-				  ;; before the function.
-				  (while (and (not (bobp))
-					      (save-excursion
-						(forward-line -1)
-						(looking-at "[^\n\f]")))
-				    (forward-line -1))
-				  (>= location (point)))
-				;; Consistency check: going down and up
-				;; shouldn't take us back before BEG.
-				(> (point) beg))
-			   (buffer-substring (point)
-					     (progn (backward-sexp 1)
-						    (point)))))))))
+		       (if (condition-case nil
+			       ;; Protect against "Unbalanced parens" error.
+			       (progn
+				 (down-list 1) ; into arglist
+				 (backward-up-list 1)
+				 (skip-chars-backward " \t")
+				 t)
+			     (error nil))
+			   ;; Verify initial pos was after
+			   ;; real start of function.
+			   (if (and (save-excursion
+				      (goto-char beg)
+				      ;; For this purpose, include the line
+				      ;; that has the decl keywords.  This
+				      ;; may also include some of the
+				      ;; comments before the function.
+				      (while (and (not (bobp))
+						  (save-excursion
+						    (forward-line -1)
+						    (looking-at "[^\n\f]")))
+					(forward-line -1))
+				      (>= location (point)))
+				    ;; Consistency check: going down and up
+				    ;; shouldn't take us back before BEG.
+				    (> (point) beg))
+			       (buffer-substring (point)
+						 (progn (backward-sexp 1)
+							(point))))))))))
 	    ((memq major-mode
 		   '(TeX-mode plain-TeX-mode LaTeX-mode;; tex-mode.el
 			      plain-tex-mode latex-mode;; cmutex.el